@@ -22,6 +22,18 @@ spec = do
             let ast = parseText "int a(void) { return 3; }"
             ast `shouldSatisfy` isRight1
 
+        it "should parse non_null annotations" $ do
+            let ast = parseText "non_null() int a(char *p);"
+            ast `shouldSatisfy` isRight1
+
+        it "should parse non_null and nullable annotations" $ do
+            let ast = parseText "non_null(2) nullable(1) int a(char *p, int *q);"
+            ast `shouldSatisfy` isRight1
+
+        it "should parse per-param non_null and nullable annotations" $ do
+            let ast = parseText "int a(non_null() char *p, non_null() int *q);"
+            ast `shouldSatisfy` isRight1
+
         it "should parse a type declaration" $ do
             let ast = parseText "typedef struct Foo { int x; } Foo;"
             ast `shouldSatisfy` isRight1
